==> xmlwrapp-0.6.2.tar.gz: xmlwrapp-0.6.2/include/xmlwrapp/_cbfo.h <==
/*
 * Copyright (C) 2001-2003 Peter J Jones (pjones@pmade.org)
 * All Rights Reserved
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Neither the name of the Author nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _xmlwrapp_cbfo_h_
#define _xmlwrapp_cbfo_h_

#include <functional>

namespace xml
{

class node;

namespace impl
{

    // helper for xml::node::sort()
    struct cbfo_node_compare
            : public std::binary_function<xml::node, xml::node, bool>
    {
        virtual ~cbfo_node_compare() {}
        virtual bool operator()(const xml::node& lhs, const xml::node& rhs) = 0;
    };

    template<typename T>
    struct sort_callback : public cbfo_node_compare
    {
        sort_callback(T& t) : t_(t) {}

        bool operator()(const xml::node& lhs, const xml::node& rhs)
            { return t_(lhs, rhs); }

        T &t_;
    };

} // namespace impl

} // namespace xml

#endif // _xmlwrapp_cbfo_h_

==> xmlwrapp-0.8.1.tar.gz: xmlwrapp-0.8.1/include/xmlwrapp/_cbfo.h <==
/*
 * Copyright (C) 2001-2003 Peter J Jones (pjones@pmade.org)
 * All Rights Reserved
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Neither the name of the Author nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _xmlwrapp_cbfo_h_
#define _xmlwrapp_cbfo_h_

// xmlwrapp includes
#include "xmlwrapp/export.h"

#include <functional>

namespace xml
{

class node;

namespace impl
{

    // helper for xml::node::sort()
    struct XMLWRAPP_API cbfo_node_compare
            : public std::binary_function<xml::node, xml::node, bool>
    {
        virtual ~cbfo_node_compare() {}
        virtual bool operator()(const xml::node& lhs, const xml::node& rhs) = 0;
    };

    template<typename T>
    struct sort_callback : public cbfo_node_compare
    {
        sort_callback(T& t) : t_(t) {}

        bool operator()(const xml::node& lhs, const xml::node& rhs)
            { return t_(lhs, rhs); }

        T &t_;
    };

} // namespace impl

} // namespace xml

#endif // _xmlwrapp_cbfo_h_
